
# This file was generated by 'versioneer.py' (0.19) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2025-07-08T13:15:47-0300",
 "dirty": true,
 "error": null,
 "full-revisionid": "34ee2ee50c7518572e66a4441078263e59ba4030",
 "version": "2.65.0"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
