(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[3296],{92812:function(e,t,n){(window.__NEXT_P=window.__NEXT_P||[]).push(["/data-catalog/[systemId]/projects/[projectUrn]/[resourceUrn]",function(){return n(93251)}])},93251:function(e,t,n){"use strict";n.r(t);var r=n(24246),c=n(86677),o=n(18225),s=n(77213),a=n(77830),u=n(58754),l=n(25077),i=n(94780),d=n(1315);t.default=()=>{var e,t;let{query:n}=(0,c.useRouter)(),_=n.systemId,f=n.projectUrn,m=n.resourceUrn,{data:p,isLoading:h}=(0,d.rn)(_),j=(0,c.useRouter)(),k=null!==(e=(0,i.X5)(m,"".concat(a.mX,"/").concat(_,"/projects")))&&void 0!==e?e:[];return h?(0,r.jsx)(o.Z,{}):(0,r.jsxs)(s.Z,{title:"Data catalog",children:[(0,r.jsx)(u.Z,{heading:"Data catalog",breadcrumbItems:[{title:"All systems",href:a.mX},{title:null!==(t=null==p?void 0:p.name)&&void 0!==t?t:null==p?void 0:p.fides_key,href:a.mX},...k]}),(0,r.jsx)(l.Z,{resourceUrn:m,onRowClick:e=>j.push("".concat(a.mX,"/").concat(p.fides_key,"/projects/").concat(f,"/").concat(e.urn))})]})}}},function(e){e.O(0,[2858,2866,9278,409,6882,3855,2888,9774,179],function(){return e(e.s=92812)}),_N_E=e.O()}]);